:orphan:

.. _about:

.. include:: ../README.rst
   :start-after: include-starts-here
   :end-before: include-ends-here

Documentation
=============

Please see :ref:`Contents <table-of-contents>` for full documentation, including installation and tutorials.

Bugs/Requests
=============

Please use the `GitHub issue tracker`_ to submit bugs or request features.


Changelog
=========

Consult the :ref:`Changelog <changelog>` page for fixes and enhancements of each version.


.. _GitHub issue tracker: https://github.com/saltstack/pytest-skip-markers/issues
